Enum oursh::program::Error [−][src]
pub enum Error {
Read,
Parse,
Runtime,
}Expand description
A comprehensive error type for the operation of programs.
Variants
A general issue reading the program.
An error within the lexer or parser.
An error encountered during the evaluation of a program.